==> v3.0.tar.gz: privacyguides.org/docs/index.nl.md <==
---
template: overrides/home.en.html
hide:
  - navigation
  - toc
  - feedback
---

<!-- markdownlint-disable-next-line -->
<div style="max-width:50rem;margin:auto;" markdown>
<div style="max-width:38rem;" markdown>
## Waarom zou ik me daar zorgen over maken?

##### "Ik heb niets te verbergen. Waarom zou ik me zorgen maken over mijn privacy?"

Net zoals het recht op interraciale huwelijken, het kiesrecht voor vrouwen, de vrijheid van meningsuiting en vele andere, hadden wij niet altijd recht op privacy. In verschillende dictaturen hebben velen dat nog steeds niet. Generaties voor ons vochten voor ons recht op privacy. ==Privacy is een mensenrecht dat inherent is aan ons allen== waar we zonder onderscheid recht op hebben.

Je moet privacy niet verwarren met geheimzinnigheid. We weten wat er in de badkamer gebeurt, maar je doet nog steeds de deur dicht. Dat is omdat je privacy wilt, geen geheimzinnigheid. **Iedereen** heeft iets te beschermen. Privacy is iets dat je menselijk maakt.

[:material-target-account: Common Internet Threats](basics/common-threats.md){ .md-button .md-button--primary }
</div>

<div style="margin-left:auto;margin-right:0;text-align:right;max-width:38rem;" markdown>
## Wat moet ik doen?

##### Eerst moet je een plan maken

Het is onpraktisch, duur en vermoeiend om te proberen al jouw gegevens altijd tegen iedereen te beschermen.

Maar maak je geen zorgen! Maar maak je geen zorgen! Veiligheid is een proces, en door vooruit te denken kunt je een plan samenstellen dat voor je geschikt is. Veiligheid gaat niet alleen over de tools die je gebruikt of de software die je downloadt. Integendeel, het begint met het begrijpen van de unieke bedreigingen waarmee je wordt geconfronteerd en hoe je deze kunt verminderen.

==Dit proces van het identificeren van bedreigingen en het vaststellen van tegenmaatregelen wordt **bedreigingsmodellering**== genoemd, en het vormt de basis van elk goed beveiligings- en privacyplan.

[:material-book-outline: Meer informatie over dreigingsmodellering](basics/threat-modeling.md){ .md-button .md-button--primary }
</div>
</div>

<div style="padding:3em;max-width:960px;margin:auto;text-align:center;" markdown>
## We hebben je nodig! Zo kunt u meedoen

Het is belangrijk voor een website als Privacy Guides om altijd up-to-date te blijven. Ons publiek moet software-updates in de gaten houden voor de toepassingen die op onze site staan en recent nieuws volgen over aanbieders die wij aanbevelen. Het is moeilijk om het hoge tempo van het internet bij te houden, maar we doen ons best. Als je een fout ziet, denkt dat een provider niet in de lijst thuishoort, merkt dat een gekwalificeerde provider ontbreekt, denkt dat een browserplugin niet langer de beste keuze is, of een ander probleem ontdekt, laat het ons dan weten.

<div class="grid cards" style="margin:auto;max-width:800px;text-align:center;" markdown>

-:simple-discourse: Word lid van ons forum](https://discuss.privacyguides.net/)
- [:simple-mastodon: Volg ons op Mastodon](https://mastodon.neat.computer/@privacyguides){ rel=me }
-:material-book-edit: Draag bij aan deze website](https://github.com/privacyguides/privacyguides.org)
- [:simple-matrix: Chat met ons op Matrix](https://matrix.to/#/#privacyguides:matrix.org)
- [:material-information-outline: Leer meer over ons](about/index.md)
- [:material-hand-coin-outline: Steun het project](about/donate.md)

</div>
</div>

==> v3.2.tar.gz: privacyguides.org/docs/index.nl.md <==
---
template: overrides/home.nl.html
hide:
  - navigation
  - toc
  - feedback
---

<!-- markdownlint-disable-next-line -->
<div style="max-width:50rem;margin:auto;" markdown>
<div style="max-width:38rem;" markdown>
## Waarom zou ik me daar zorgen over maken?

##### "Ik heb niets te verbergen. Waarom zou ik me zorgen maken over mijn privacy?"

Net zoals het recht op interraciale huwelijken, het kiesrecht voor vrouwen, de vrijheid van meningsuiting en vele andere, hadden wij niet altijd recht op privacy. In verschillende dictaturen hebben velen dat nog steeds niet. Generaties voor ons vochten voor ons recht op privacy. ==Privacy is een mensenrecht dat inherent is aan ons allen== waar we zonder onderscheid recht op hebben.

Je moet privacy niet verwarren met geheimzinnigheid. We weten wat er in de badkamer gebeurt, maar je doet nog steeds de deur dicht. Dat is omdat je privacy wilt, geen geheimzinnigheid. **Iedereen** heeft iets te beschermen. Privacy is iets dat je menselijk maakt.

[:material-target-account: Common Internet Threats](basics/common-threats.md){ .md-button .md-button--primary }
</div>

<div style="margin-left:auto;margin-right:0;text-align:right;max-width:38rem;" markdown>
## Wat moet ik doen?

##### Eerst moet je een plan maken

Het is onpraktisch, duur en vermoeiend om te proberen al jouw gegevens altijd tegen iedereen te beschermen. Maar maak je geen zorgen! Veiligheid is een proces, en door vooruit te denken kunt je een plan samenstellen dat voor je geschikt is. Veiligheid gaat niet alleen over de tools die je gebruikt of de software die je downloadt. Integendeel, het begint met het begrijpen van de unieke bedreigingen waarmee je wordt geconfronteerd en hoe je deze kunt verminderen.

==Dit proces van het identificeren van bedreigingen en het vaststellen van tegenmaatregelen wordt **bedreigingsmodellering**== genoemd, en het vormt de basis van elk goed beveiligings- en privacyplan.

[:material-book-outline: Meer informatie over dreigingsmodellering](basics/threat-modeling.md){ .md-button .md-button--primary }
</div>
</div>

<div style="padding:3em;max-width:960px;margin:auto;text-align:center;" markdown>
## We hebben je nodig! Zo kunt u meedoen

Het is belangrijk voor een website als Privacy Guides om altijd up-to-date te blijven. Ons publiek moet software-updates in de gaten houden voor de toepassingen die op onze site staan en recent nieuws volgen over aanbieders die wij aanbevelen. Het is moeilijk om het hoge tempo van het internet bij te houden, maar we doen ons best. Als je een fout ziet, denkt dat een provider niet in de lijst thuishoort, merkt dat een gekwalificeerde provider ontbreekt, denkt dat een browserplugin niet langer de beste keuze is, of een ander probleem ontdekt, laat het ons dan weten.

<div class="grid cards" style="margin:auto;max-width:800px;text-align:center;" markdown>

- [:simple-discourse: Word lid van ons forum](https://discuss.privacyguides.net/)
- [:simple-mastodon: Volg ons op Mastodon](https://mastodon.neat.computer/@privacyguides){ rel=me }
- [:material-book-edit: Draag bij aan deze website](https://github.com/privacyguides/privacyguides.org)
- [:simple-matrix: Chat met ons op Matrix](https://matrix.to/#/#privacyguides:matrix.org)
- [:material-information-outline: Leer meer over ons](about/index.md)
- [:material-hand-coin-outline: Steun het project](about/donate.md)

</div>
</div>
